@@ -1,11 +1,10 @@
-require 'zurb-foundation'
 # Require any additional compass plugins here.
 
 
 # Set this to the root of your project when deployed:
 http_path = "/"
 css_dir = "css"
-sass_dir = "sass"
+sass_dir = "scss"
 images_dir = "img"
 javascripts_dir = "js"
 
